@@ -1,19 +1,19 @@
 /*
- * Copyright (C) 2018 Mark Hills <mark@xwax.org>
+ * Copyright (C) 2021 Mark Hills <mark@xwax.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * version 2, as published by the Free Software Foundation.
+ * This file is part of "xwax".
  *
- * This program is distributed in the hope that it will be useful, but
+ * "xwax" is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License, version 3 as
+ * published by the Free Software Foundation.
+ *
+ * "xwax" is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License version 2 for more details.
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * version 2 along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -33,6 +33,7 @@
 #include <SDL.h>
 #include <SDL_ttf.h>
 
+#include "debug.h"
 #include "interface.h"
 #include "layout.h"
 #include "player.h"
@@ -192,7 +193,7 @@ static int zoom(int d)
  * Convert the given time (in milliseconds) to displayable time
  */
 
-static void time_to_clock(char *buf, char *deci, int t)
+static void time_to_clock(char buf[9], char deci[4], int t)
 {
     int minutes, seconds, frac;
     bool neg;
@@ -677,7 +678,7 @@ static void draw_record(SDL_Surface *surface, const struct rect *rect,
 static void draw_clock(SDL_Surface *surface, const struct rect *rect, int t,
                        SDL_Color col)
 {
-    char hms[8], deci[8];
+    char hms[9], deci[4];
     short int v;
     struct rect sr;
 
@@ -1750,12 +1751,12 @@ static void* launch(void *p)
  * Parse and action the given geometry string
  *
  * Geometry string includes size, position and scale. The format is
- * "[<n>x<n>][+<n>+<n>][@<f>]". Some examples:
+ * "[<n>x<n>][+<n>+<n>][/<f>]". Some examples:
  *
  *   960x720
  *   +10+10
  *   960x720+10+10
- *   @1.6
+ *   /1.6
  *   1920x1200@1.6
  *
  * Return: -1 if string could not be actioned, otherwise 0
@@ -1825,85 +1826,13 @@ static int parse_geometry(const char *s)
 }
 
 /*
- * Start the SDL interface
- *
- * FIXME: There are multiple points where resources are leaked on
- * error
+ * Cleanup resources associated with this user interface
  */
 
-int interface_start(struct library *lib, const char *geo, bool decor)
+static void cleanup()
 {
     size_t n;
 
-    if (parse_geometry(geo) == -1) {
-        fprintf(stderr, "Window geometry ('%s') is not valid.\n", geo);
-        return -1;
-    }
-
-    if (!decor)
-        video_flags |= SDL_NOFRAME;
-
-    for (n = 0; n < ndeck; n++) {
-        if (timecoder_monitor_init(&deck[n].timecoder, zoom(SCOPE_SIZE)) == -1)
-            return -1;
-    }
-
-    if (init_spinner(zoom(SPINNER_SIZE)) == -1)
-        return -1;
-
-    selector_init(&selector, lib);
-    watch(&on_status, &status_changed, defer_status_redraw);
-    watch(&on_selector, &selector.changed, defer_selector_redraw);
-    status_set(STATUS_VERBOSE, banner);
-
-    fprintf(stderr, "Initialising SDL...\n");
-
-    if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) == -1) {
-        fprintf(stderr, "%s\n", SDL_GetError());
-        return -1;
-    }
-    SDL_WM_SetCaption(banner, NULL);
-    SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
-
-    /* Initialise the fonts */
-
-    if (TTF_Init() == -1) {
-        fprintf(stderr, "%s\n", TTF_GetError());
-        return -1;
-    }
-
-    if (load_fonts() == -1)
-        return -1;
-
-    utf = iconv_open("UTF8", "");
-    if (utf == (iconv_t)-1) {
-        perror("iconv_open");
-        return -1;
-    }
-
-    fprintf(stderr, "Launching interface thread...\n");
-
-    if (pthread_create(&ph, NULL, launch, NULL)) {
-        perror("pthread_create");
-        return -1;
-    }
-
-    return 0;
-}
-
-/*
- * Synchronise with the SDL interface and exit
- */
-
-void interface_stop(void)
-{
-    size_t n;
- 
-    push_event(EVENT_QUIT);
-
-    if (pthread_join(ph, NULL) != 0)
-        abort();
-
     for (n = 0; n < ndeck; n++)
         timecoder_monitor_clear(&deck[n].timecoder);
 
@@ -1919,3 +1848,113 @@ void interface_stop(void)
     TTF_Quit();
     SDL_Quit();
 }
+
+/*
+ * Start the SDL interface
+ */
+
+int interface_start(struct library *lib, const char *geo, bool decor)
+{
+    size_t n;
+
+    if (parse_geometry(geo) == -1) {
+        fprintf(stderr, "Window geometry ('%s') is not valid.\n", geo);
+        return -1;
+    }
+
+    if (!decor)
+        video_flags |= SDL_NOFRAME;
+
+    /*
+     * Start allocating resources
+     *
+     * Many exit paths here; get the ones most likely to fail (user error)
+     * out of the way first.
+     */
+
+    /*
+     * Fonts
+     */
+
+    fprintf(stderr, "Initialising fonts...\n");
+
+    if (TTF_Init() == -1) {
+        fprintf(stderr, "%s\n", TTF_GetError());
+        return -1;
+    }
+
+    if (load_fonts() == -1) {
+        goto fail_fonts;
+    }
+
+    /*
+     * SDL
+     */
+
+    fprintf(stderr, "Initialising SDL...\n");
+
+    if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) == -1) {
+        fprintf(stderr, "%s\n", SDL_GetError());
+        goto fail_fonts;
+    }
+
+    SDL_WM_SetCaption(banner, NULL);
+    SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
+
+    /*
+     * Character translations; internally UTF8 is used
+     */
+
+    utf = iconv_open("UTF8", "");
+    if (utf == (iconv_t)-1) {
+        perror("iconv_open");
+        goto fail_sdl;
+    }
+
+    /*
+     * Timecode monitors
+     */
+
+    if (init_spinner(zoom(SPINNER_SIZE)) == -1)
+        goto fail_sdl;
+
+    for (n = 0; n < ndeck; n++) {
+        if (timecoder_monitor_init(&deck[n].timecoder, zoom(SCOPE_SIZE)) == -1)
+            not_implemented();
+    }
+
+    selector_init(&selector, lib);
+    watch(&on_status, &status_changed, defer_status_redraw);
+    watch(&on_selector, &selector.changed, defer_selector_redraw);
+    status_set(STATUS_VERBOSE, banner);
+
+    fprintf(stderr, "Launching interface thread...\n");
+
+    if (pthread_create(&ph, NULL, launch, NULL)) {
+        perror("pthread_create");
+        cleanup();
+        return -1;
+    }
+
+    return 0;
+
+fail_sdl:
+    SDL_Quit();
+fail_fonts:
+    TTF_Quit();
+    return -1;
+}
+
+/*
+ * Synchronise with the SDL interface and exit
+ */
+
+void interface_stop(void)
+{
+    push_event(EVENT_QUIT);
+
+    if (pthread_join(ph, NULL) != 0)
+        abort();
+
+    cleanup();
+}
