@@ -1,19 +1,19 @@
 /*
- * Copyright (C) 2018 Mark Hills <mark@xwax.org>
+ * Copyright (C) 2021 Mark Hills <mark@xwax.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * version 2, as published by the Free Software Foundation.
+ * This file is part of "xwax".
  *
- * This program is distributed in the hope that it will be useful, but
+ * "xwax" is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License, version 3 as
+ * published by the Free Software Foundation.
+ *
+ * "xwax" is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License version 2 for more details.
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * version 2 along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -125,6 +125,28 @@ static struct timecode_def timecodes[] = {
         .length = 312000,
         .safe = 310000,
     },
+    {
+        .name = "pioneer_a",
+        .desc = "Pioneer RekordBox DVS Control Vinyl, side A",
+        .resolution = 1000,
+        .flags = SWITCH_POLARITY,
+        .bits = 20,
+        .seed = 0x78370,
+        .taps = 0x7933a,
+        .length = 635000,
+        .safe = 614000,
+    },
+    {
+        .name = "pioneer_b",
+        .desc = "Pioneer RekordBox DVS Control Vinyl, side B",
+        .resolution = 1000,
+        .flags = SWITCH_POLARITY,
+        .bits = 20,
+        .seed = 0xf7012,
+        .taps = 0x2ef1c,
+        .length = 918500,
+        .safe = 913000,
+    },
 };
 
 /*
@@ -202,12 +224,12 @@ static int build_lookup(struct timecode_def *def)
         bits_t next;
 
         /* timecode must not wrap */
-        dassert(lut_lookup(&def->lut, current) == (unsigned)-1);
+        assert(lut_lookup(&def->lut, current) == (unsigned)-1);
         lut_push(&def->lut, current);
 
         /* check symmetry of the lfsr functions */
         next = fwd(current, def);
-        dassert(rev(next, def) == current);
+        assert(rev(next, def) == current);
 
         current = next;
     }
@@ -220,30 +242,26 @@ static int build_lookup(struct timecode_def *def)
 /*
  * Find a timecode definition by name
  *
- * Return: pointer to timecode definition, or NULL if not found
+ * Return: pointer to timecode definition, or NULL if not available
  */
 
 struct timecode_def* timecoder_find_definition(const char *name)
 {
-    struct timecode_def *def, *end;
+    unsigned int n;
 
-    def = &timecodes[0];
-    end = def + ARRAY_SIZE(timecodes);
+    for (n = 0; n < ARRAY_SIZE(timecodes); n++) {
+        struct timecode_def *def = &timecodes[n];
 
-    for (;;) {
-        if (!strcmp(def->name, name))
-            break;
+        if (strcmp(def->name, name) != 0)
+            continue;
 
-        def++;
+        if (build_lookup(def) == -1)
+            return NULL;  /* error */
 
-        if (def == end)
-            return NULL;
+        return def;
     }
 
-    if (build_lookup(def) == -1)
-        return NULL;
-
-    return def;
+    return NULL;  /* not found */
 }
 
 /*
@@ -251,15 +269,13 @@ struct timecode_def* timecoder_find_definition(const char *name)
  */
 
 void timecoder_free_lookup(void) {
-    struct timecode_def *def, *end;
+    unsigned int n;
 
-    def = &timecodes[0];
-    end = def + ARRAY_SIZE(timecodes);
+    for (n = 0; n < ARRAY_SIZE(timecodes); n++) {
+        struct timecode_def *def = &timecodes[n];
 
-    while (def < end) {
         if (def->lookup)
             lut_clear(&def->lut);
-        def++;
     }
 }
 
@@ -405,7 +421,7 @@ static void update_monitor(struct timecoder *tc, signed int x, signed int y)
 
     assert(ref > 0);
 
-    /* ref_level is half the prevision of signal level */
+    /* ref_level is half the precision of signal level */
     px = size / 2 + (long long)x * size / ref / 8;
     py = size / 2 + (long long)y * size / ref / 8;
 
@@ -544,7 +560,7 @@ static struct timecode_def* next_definition(struct timecode_def *def)
     do {
         def++;
 
-        if (def > timecodes + ARRAY_SIZE(timecodes))
+        if (def >= timecodes + ARRAY_SIZE(timecodes))
             def = timecodes;
 
     } while (!def->lookup);
